# Scrcpy Client V3.0
<p>
    <img src="https://img.shields.io/github/license/leng-yue/py-scrcpy-client" />
    <a href="https://pepy.tech/projects/scrcpy-core" target="_blank">
        <img src="https://static.pepy.tech/badge/scrcpy-core" />
    </a>
    <a href="https://github.com/Genymobile/scrcpy/releases/tag/v3.1" target="_blank">
        <img src="https://img.shields.io/badge/scrcpy-v3.10-violet" />
    </a>
</p>



Scrcpy Client 升级scrcpy核心3.0，去除了ui控制面板，只保留了core

![demo gif](https://raw.githubusercontent.com/leng-yue/py-scrcpy-client/main/demo.gif) 

Note: 这个gif是之前的演示

## 如何使用
pip安装即可
```shell
pip install scrcpy-core
```
